@@ -143,7 +143,7 @@ class MysqlErrorHandlingMixin(object):
 
         if colum == "url":
             sql = f"ALTER TABLE `{table}` ADD COLUMN `{colum}` TEXT(500) NULL COMMENT '{notes}';"
-        elif colum in ["create_time", "crawl_time"]:
+        elif colum in {"create_time", "crawl_time", "update_time"}:
             sql = f"ALTER TABLE `{table}` ADD COLUMN `{colum}` DATE NULL DEFAULT NULL COMMENT '{notes}';"
         else:
             sql = f"ALTER TABLE `{table}` ADD COLUMN `{colum}` VARCHAR(190) NULL DEFAULT '' COMMENT '{notes}';"
